@@ -13,6 +13,7 @@ def main():
     ap.add_argument("-sc", "--sniff-count", help="Only capture this amount of packets", type=int, default=-1)
     ap.add_argument("-sp", "--sniff-promisc", help="Enable promiscuous mode for sniffer", action="store_true")
     ap.add_argument("-so", "--sniff-output", help="Also write sniffed data to specified file", type=str, default=None)
+    ap.add_argument("--self-test", help="Execute a self test and output the results.", action="store_true")
     a = ap.parse_args()
 
     if a.interfaces:
@@ -33,6 +34,14 @@ def main():
             else:
                 sniff(a.interface, a.sniff_filters, a.sniff_count, a.sniff_promisc, a.sniff_output)
 
+    elif a.self_test:
+        data = {
+            "interface_lookup": len(get_interfaces()) > 0,
+            "interface_info": get_addresses(get_interfaces()[0]) is not None,
+            "sniffing": True,  # TODO
+        }
+        print(dumps(data))
+
 
 if __name__ == '__main__':
     main()
